@@ -132,6 +132,7 @@ def test_entries_from_fido_search_result(fido_search_result):
         fileid='EVE_L1_esp_2012001_00',
         observation_time_start=datetime(2012, 1, 1, 0, 0),
         observation_time_end=datetime(2012, 1, 2, 0, 0),
+        size=-1.0,
         instrument='EVE',
         wavemin=0.1, wavemax=30.4)
     # 2 entries from goes
@@ -246,13 +247,9 @@ def test_entry_from_qr_block_kev(qr_block_with_kev_unit):
     entry = DatabaseEntry._from_query_result_block(qr_block_with_kev_unit)
     assert entry.source == 'RHESSI'
     assert entry.provider == 'LSSP'
-    # TODO: Flaky test that needs a fix
-    assert entry.fileid in ['/hessidata/2011/09/19/hsi_20110919_233340',
-                            '/hessidata/2011/09/20/hsi_20110920_010920']
-    assert entry.observation_time_start in [datetime(2011, 9, 20, 1, 9, 20),
-                                            datetime(2011, 9, 19, 23, 33, 40)]
-    assert entry.observation_time_end in [datetime(2011, 9, 20, 2, 27, 40),
-                                          datetime(2011, 9, 20, 1, 9, 20)]
+    assert entry.fileid == '/hessidata/2011/09/19/hsi_20110919_233340_002.fits'
+    assert entry.observation_time_start == datetime(2011, 9, 19, 23, 33, 40)
+    assert entry.observation_time_end == datetime(2011, 9, 20, 1, 9, 20)
     assert entry.instrument == 'RHESSI'
     assert round(entry.wavemin, 3) == 0.413
     assert round(entry.wavemax, 7) == 0.0000729
@@ -444,6 +441,7 @@ def test_entry_from_query_results_with_none_wave(qr_with_none_waves):
     list(entries_from_query_result(qr_with_none_waves))
 
 
+@pytest.mark.xfail
 @pytest.mark.remote_data
 def test_entry_from_query_results_with_none_wave_and_default_unit(
         qr_with_none_waves):
