@@ -38,7 +38,7 @@ def download_weekly_pointing_file(date):
     # use a temp directory to hold the file
     tmp_dir = tempfile.mkdtemp()
     # use Fermi data server to access weekly LAT pointing file.
-    base_url = 'ftp://legacy.gsfc.nasa.gov/FTP/glast/data/lat/weekly/spacecraft/'
+    base_url = 'https://heasarc.gsfc.nasa.gov/FTP/fermi/data/lat/weekly/spacecraft/'
     fbasename = 'lat_spacecraft_weekly_w'
 
     # find out which file to get based on date
@@ -52,13 +52,13 @@ def download_weekly_pointing_file(date):
     weekdiff = time_diff.to(u.day).value // 7
     week = weekdiff + base_week
     # weekstr = ('%03.0f' % week)
-    weekstr = '{:03.0f}'.format(week)
+    weekstr = f'{week:03.0f}'
 
     # construct the full url for the weekly pointing file
     full_fname = fbasename + weekstr + '_p202_v001.fits'
     pointing_file_url = base_url + full_fname
 
-    # try to download the file from the FTP site
+    # try to download the file
     try:
         resp = urllib.request.urlopen(pointing_file_url)
         exists = True
